camelot.camelot.model.authentication.SharedShareholder

Package camelot :: Package camelot :: Package model :: Module authentication :: Class SharedShareholder |
[hide private]
[frames] | no frames]

# Class SharedShareholder

source code

Relation from a shared organization to a shareholder

Nested Classes | [hide private]
| ShareholderAdmin
| SharedAdmin

Class Variables | [hide private]
| established_from = `ManyToOne('Organization', required= True, o`...``
| established_to = `ManyToOne('Party', required= True, ondelete= `...``
| shares = `Field(Integer())`
Inherited from `PartyRelationship`: `comment`, `from_date`, `thru_date`

Class Variable Details | [hide private]

  ### established_from Value:
      ManyToOne('Organization', required= True, ondelete= 'cascade', onupdat
      e= 'cascade')

  ### established_to Value:
      ManyToOne('Party', required= True, ondelete= 'cascade', onupdate= 'cas
      cade')